---
sidebar_label: dict
title: data_structures.predefined.dict
---

## Dict Objects

```python
class Dict(ObjectDS)
```

This class serializes python dict

soil.data(my_dict) will create a dict automatically.

#### unserialize

```python
 | @staticmethod
 | unserialize(json_data, metadata)
```

Deprecated method. It can be removed in a few months.

